@@ -20,9 +20,9 @@ class Url2Html(object):
         self.data_src_re = re.compile(r'data-src="(.*?)"')
         self.data_croporisrc_re = re.compile(r'data-croporisrc="(.*?)"')
         self.src_re = re.compile(r'src="(.*?)"')
-        self.img_path = img_path
 
-    def replace_name(self, title):
+    @staticmethod
+    def replace_name(title):
         """
         对进行标题替换，确保标题符合windows的命名规则
 
@@ -52,19 +52,18 @@ class Url2Html(object):
         """
         # 根据链接提取图片名
         name = "{}.{}".format(url.split("/")[-2], url.split("/")[3].split("_")[-1])
-        imgpath = os.path.join(self.img_path, name)
+        save_path = os.path.join(self.account, "imgs", name)
         # 如果该图片已被下载，可以无需再下载，直接返回路径即可
-        if os.path.isfile(imgpath):
-            with open(imgpath, "rb") as f:
+        if os.path.isfile(save_path):
+            with open(save_path, "rb") as f:
                 img = f.read()
-            return imgpath, img
+            return os.path.join("imgs", name), img
 
         response = requests.get(url, proxies=self.proxies)
         img = response.content
-        with open(imgpath, "wb") as f:
+        with open(save_path, "wb") as f:
             f.write(img)
-        imgpath = os.path.basename(self.img_path)
-        return os.path.join(imgpath, name), img
+        return os.path.join("imgs", name), img
 
     def replace_img(self, html):
         """
@@ -87,14 +86,14 @@ class Url2Html(object):
         img_lst = []
         for img_url in img_url_lst:
             if "mmbiz.qpic.cn" in img_url:
-                # print(img_url)
                 data_src, img = self.download_img(img_url)
                 img_lst.append([data_src, img])
                 # 以绝对路径的方式替换图片
                 html = html.replace(img_url, data_src).replace("data-src=", "src=")
         return html, img_lst
 
-    def get_title(self, html):
+    @staticmethod
+    def get_title(html):
         """
         根据提供的html源码提取文章中的标题
 
@@ -116,7 +115,8 @@ class Url2Html(object):
             print(html.split("<h2")[1].split("</h2")[0])
             return ""
 
-    def article_info(self, html):
+    @staticmethod
+    def article_info(html):
         """
         根据提供的html源码提取文章中的公众号和作者
 
@@ -138,7 +138,8 @@ class Url2Html(object):
         author = html.split('id="js_name">')[1].split("</a")[0].strip()
         return account, author
 
-    def get_timestamp(self, html):
+    @staticmethod
+    def get_timestamp(html):
         """
         根据提供的html源码提取文章发表的时间戳
 
@@ -154,7 +155,8 @@ class Url2Html(object):
         timestamp = int(html.split('ct = "')[1].split('";')[0].strip())
         return timestamp
 
-    def timestamp2date(self, timestamp):
+    @staticmethod
+    def timestamp2date(timestamp):
         """
         时间戳转日期
 
@@ -184,6 +186,7 @@ class Url2Html(object):
                 account_name = self.article_info(html)[0]
             except:
                 account_name = "未分类"
+            self.account = account_name
         else:
             account_name = self.account
         try:
@@ -203,7 +206,8 @@ class Url2Html(object):
         )
         return title
 
-    def download_media(self, html, title):
+    @staticmethod
+    def download_media(html, title):
         soup = bs(html, "lxml")
         # mp3
         mpvoice_item_lst = soup.find_all("mpvoice")
@@ -227,6 +231,10 @@ class Url2Html(object):
                 with open("{}.mp4".format(title), "wb") as f:
                     f.write(doc.content)
 
+    @staticmethod
+    def test_replace_img(html):
+        return html.replace("data-src=", "src=").replace("wx_fmt=jpeg", "wx_fmt=web")
+
     def run(self, url, mode, proxies={"http": None, "https": None}, **kwargs):
         """
         Parameters
@@ -240,12 +248,12 @@ class Url2Html(object):
             3: 返回html源码，下载图片且替换图片路径
             4: 保存html源码，下载图片且替换图片路径
             5: 保存html源码，下载图片且替换图片路径，并下载视频与音频
+            6: 返回html源码，不下载图片，替换src和图片为web
         kwargs:
             account: 公众号名
             title: 文章名
             date: 日期
             proxies: 代理
-            img_path: 图片下载路径
 
         Returns
         ----------
@@ -254,11 +262,9 @@ class Url2Html(object):
         self.proxies = proxies
         if mode == 1:
             return requests.get(url, proxies=proxies).text
+        elif mode == 6:
+            return self.test_replace_img(requests.get(url, proxies=proxies).text)
         elif mode in [2, 3, 4, 5]:
-            if "img_path" in kwargs.keys():
-                self.img_path = kwargs["img_path"]
-            else:
-                return "{} 请输入保存图片路径!".format(url)
             if mode == 2:
                 return requests.get(url, proxies=proxies).text
             elif mode == 3:
@@ -285,6 +291,8 @@ class Url2Html(object):
                     html = requests.get(url, proxies=proxies).text
                     title = self.rename_title(title, html)
 
+                if not os.path.isdir(os.path.join(self.account, "imgs")):
+                    os.makedirs(os.path.join(self.account, "imgs"))
                 if mode == 5:
                     try:
                         self.download_media(html, title)
@@ -307,5 +315,5 @@ if __name__ == "__main__":
     ]
     uh = Url2Html()
     for url in url_lst:
-        s = uh.run(url, mode=4, img_path="D:\\imgs")
+        s = uh.run(url, mode=4)
         print(s)
